#!/bin/bash

export COMPONENT_HASH=88290e72f0abe900bee0a14eaf26947a8e33c7a3
PKG_VERSION=0.4.15+cdh6.2.1
FULL_VERSION=0.4.15-cdh6.2.1
BASE_VERSION=0.4.15
PKG_RELEASE=1425774
CDH_CUSTOMER_PATCH=p0
CDH_PARCEL_CUSTOM_VERSION=0.4.15+cdh6.2.1-1425774.xenial
